from .stats import Stats
from .errors import PlayerNotFound, InvalidKey
import aiohttp
import asyncio


class ClientBase:
    def __init__(self, key: str):
        self.key = key

    async def _get_uuid(self, username):
        async with aiohttp.ClientSession() as session:
            async with session.get(
                url=f"https://api.mojang.com/users/profiles/minecraft/{username}",
            ) as data:
                jsonData = await data.json()
                self.username = jsonData["id"]

    async def _get_user(self, username):
        uuid = await self._get_uuid(username)
        async with aiohttp.ClientSession() as session:
            async with session.get(
                    url="https://xincraft.net/api/v1/player/uuid/" + uuid,
                    headers={
                        "xincraft-api": self.key
                    }
            ) as data:
                jsonData = await data.json()
                if jsonData["success"]:
                    return Stats(jsonData)
                else:
                    if jsonData["cause"] == "Invalid authorization details":
                        raise InvalidKey(
                            f"Invalid authorization details: {self.key} is not a valid API key."
                        )
                    elif jsonData["cause"] == "Invalid uuid or player has never joined":
                        raise PlayerNotFound(
                            f"Invalid uuid or player has not joined: {uuid} is not a valid UUID."
                        )


class AsyncClient(ClientBase):
    def __init__(self, key: str):
        super().__init__(key)

    async def get_user(self, username: str):
        return await self._get_user(username)


class SyncClient(ClientBase):
    def __init__(self, key: str):
        super().__init__(key)

    def get_user(self, username: str):
        asyncio.run(self._get_user(username))
